# -*- coding: utf-8 -*-

"""Top-level package for whitebox."""

__author__ = """Qiusheng Wu"""
__email__ = 'giswqs@gmail.com'
__version__ = '1.5.2'

from .whitebox import *


